@@ -25,38 +25,34 @@ class ListDownStreamBindingsRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'amqp-open', '2019-12-12', 'ListDownStreamBindings','onsproxy')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ExchangeName(self):
+	def get_ExchangeName(self): # String
 		return self.get_query_params().get('ExchangeName')
 
-	def set_ExchangeName(self,ExchangeName):
-		self.add_query_param('ExchangeName',ExchangeName)
-
-	def get_InstanceId(self):
+	def set_ExchangeName(self, ExchangeName):  # String
+		self.add_query_param('ExchangeName', ExchangeName)
+	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
-	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
-
-	def get_NextToken(self):
+	def set_InstanceId(self, InstanceId):  # String
+		self.add_query_param('InstanceId', InstanceId)
+	def get_NextToken(self): # String
 		return self.get_query_params().get('NextToken')
 
-	def set_NextToken(self,NextToken):
-		self.add_query_param('NextToken',NextToken)
-
-	def get_MaxResults(self):
+	def set_NextToken(self, NextToken):  # String
+		self.add_query_param('NextToken', NextToken)
+	def get_MaxResults(self): # Integer
 		return self.get_query_params().get('MaxResults')
 
-	def set_MaxResults(self,MaxResults):
-		self.add_query_param('MaxResults',MaxResults)
-
-	def get_VirtualHost(self):
+	def set_MaxResults(self, MaxResults):  # Integer
+		self.add_query_param('MaxResults', MaxResults)
+	def get_VirtualHost(self): # String
 		return self.get_query_params().get('VirtualHost')
 
-	def set_VirtualHost(self,VirtualHost):
-		self.add_query_param('VirtualHost',VirtualHost)
\ No newline at end of file
+	def set_VirtualHost(self, VirtualHost):  # String
+		self.add_query_param('VirtualHost', VirtualHost)
